@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"net/http"
+	"strings"
 	"testing"
 
 	"golang.org/x/net/context"
@@ -21,8 +22,12 @@ func TestContainerKillError(t *testing.T) {
 }
 
 func TestContainerKill(t *testing.T) {
+	expectedURL := "/containers/container_id/kill"
 	client := &Client{
 		transport: newMockClient(nil, func(req *http.Request) (*http.Response, error) {
+			if !strings.HasPrefix(req.URL.Path, expectedURL) {
+				return nil, fmt.Errorf("Expected URL '%s', got '%s'", expectedURL, req.URL)
+			}
 			signal := req.URL.Query().Get("signal")
 			if signal != "SIGKILL" {
 				return nil, fmt.Errorf("signal not set in URL query properly. Expected 'SIGKILL', got %s", signal)
