@@ -7,6 +7,7 @@ import (
 	"net/http"
 	"strings"
 	"testing"
+	"time"
 
 	"golang.org/x/net/context"
 )
@@ -15,7 +16,8 @@ func TestContainerRestartError(t *testing.T) {
 	client := &Client{
 		transport: newMockClient(nil, errorMock(http.StatusInternalServerError, "Server error")),
 	}
-	err := client.ContainerRestart(context.Background(), "nothing", 0)
+	timeout := 0*time.Second
+	err := client.ContainerRestart(context.Background(), "nothing", &timeout)
 	if err == nil || err.Error() != "Error response from daemon: Server error" {
 		t.Fatalf("expected a Server Error, got %v", err)
 	}
@@ -38,8 +40,8 @@ func TestContainerRestart(t *testing.T) {
 			}, nil
 		}),
 	}
-
-	err := client.ContainerRestart(context.Background(), "container_id", 100)
+	timeout := 100*time.Second
+	err := client.ContainerRestart(context.Background(), "container_id", &timeout)
 	if err != nil {
 		t.Fatal(err)
 	}
